#ifndef __spxPolyDataToImageDataFilterV2_h
#define __spxPolyDataToImageDataFilterV2_h

#include "vtkImageAlgorithm.h"

class vtkPolyData;

class VTK_EXPORT PolyDataToImageData : public vtkImageAlgorithm
{
public:
	static PolyDataToImageData *New();
	vtkTypeMacro(PolyDataToImageData, vtkImageAlgorithm);
	void PrintSelf(ostream& os, vtkIndent indent);

	// Description:
	// see vtkAlgorithm for details
	virtual int ProcessRequest(vtkInformation*,
		vtkInformationVector**,
		vtkInformationVector*);
	
	//@{
	/**
	* Set voxel size (mm x mm x mm)
	*/
	vtkGetVector3Macro(VoxelSize, double);
	vtkSetVector3Macro(VoxelSize, double);
	//@}

protected:
	PolyDataToImageData();
	~PolyDataToImageData();

	// convenience method
	virtual int RequestInformation(
		vtkInformation* request,
		vtkInformationVector** inputVector,
		vtkInformationVector* outputVector) override;

	// Description:
	// This is called by the superclass.
	// This is the method you should override.
	virtual int RequestData(
		vtkInformation* request,
		vtkInformationVector** inputVector,
		vtkInformationVector* outputVector) override;

	virtual int FillInputPortInformation(int port, vtkInformation* info) override;

	virtual int RequestUpdateExtent(vtkInformation *,
		vtkInformationVector **,
		vtkInformationVector *) override;

private:
	PolyDataToImageData(const PolyDataToImageData&) = delete;
	void operator = (const PolyDataToImageData&) = delete;

	int CalculateImageProperties(vtkPolyData* input);

	double Origin[3] = { 0.0 };
	double Scale[3] = { 0.0 };
	double Spacing[3] = { 0.0 };
	int Resolution[3] = { 0 };

	double VoxelSize[3];
};

#endif // __spxPolyDataToImageDataFilterV2_h
